<?php
/**
* Add theme admin page
*
* @since 	 1.0
* @author nouthemes [nouthemes@gmail.com] 
* @code 	 Nam
*/ 
defined( 'ABSPATH' ) OR exit;

class Noubakery_Theme_Admin
{

	/**
	* Main
	*
	* @author nouthemes [nouthemes@gmail.com]
	* @since 1.0
	* @static
	* @return Main
	*/
	public static function init() 
	{
		self::options();
		add_action( 'show_user_profile', array(__CLASS__, 'extra_user_profile_fields') );
		add_action( 'edit_user_profile', array(__CLASS__, 'extra_user_profile_fields') );
		add_action( 'personal_options_update', array(__CLASS__, 'save_extra_user_profile_fields') );
		add_action( 'edit_user_profile_update', array(__CLASS__, 'save_extra_user_profile_fields') );
		add_action( 'woocommerce_product_options_advanced', array(__CLASS__, 'product_options_label') );
		add_action( 'save_post', array(__CLASS__, 'product_options_label_save') );

		if ( function_exists( 'register_block_type' ) ) {
			$post_type = isset($_GET['post_type']) ? $_GET['post_type'] : 'post';
			if( $post_type === 'page' ) {
				add_action( 'enqueue_block_editor_assets', array(__CLASS__, 'gutenberg_editor_assets') );
			}
		}	
		
	}

	public static function gutenberg_editor_assets(){
		wp_enqueue_script(
			'noubakery-gutenberg-page-template-class',
			NOUBAKERY_JS . '/gutenberg.js',
			array(
				'wp-editor',
				'wp-element',
				'wp-compose',
				'wp-data',
				'wp-plugins',
				),
			NOUBAKERY_VER,
			true
		);
	}

	public static function product_options_label_save( $post_id ) {
		if ( wp_is_post_revision( $post_id ) )
			return;

		if(isset($_POST['_product_label'])){
			update_post_meta($post_id, '_product_label', $_POST['_product_label']);
		}
	}

	public static function product_options_label(){
		global $post;
		$meta = get_post_meta($post->ID, '_product_label', true);
		?>
		<div class="options_group product_label">
			<p class="form-field">
				<label for="_product_label"><?php esc_html_e("Label type: ", 'noucake'); ?></label>
				<select id="_product_label" name="_product_label" class="select short">
					<option value="default"><?php esc_html_e("Default", 'noucake'); ?></option>
					<option value="new" <?php selected($meta, 'new');?>><?php esc_html_e("New", 'noucake'); ?></option>
					<option value="hot" <?php selected($meta, 'hot');?>><?php esc_html_e("Hot", 'noucake'); ?></option>
				</select>
			</p>
		</div>
		<?php
	}

	public static function extra_user_profile_fields( $user ){
		?>
		<table class="form-table">
			<tr>
				<th><label for="position"><?php esc_html_e("Position", 'noucake'); ?></label></th>
				<td>
				    <input type="text" name="position" id="position" class="regular-text" 
				        value="<?php echo esc_attr( get_the_author_meta( 'position', $user->ID ) ); ?>" />
				</td>
			</tr>
		</table>
		<?php
	}

	public static function save_extra_user_profile_fields( $user_id ) {
	  	$saved = false;
	  	if ( current_user_can( 'edit_user', $user_id ) ) {
	    	update_user_meta( $user_id, 'position', $_POST['position'] );
	    	$saved = true;
	  	}
	  	return true;
	}

	/**
	* Include lib for admin
	*
	* @since 	 1.0
	* @author nouthemes [nouthemes@gmail.com] 
	* @code 	 Nam
	*/
	public static function options()
	{

		/**
		* TGM-Plugin-Activation
		* https://github.com/TGMPA/TGM-Plugin-Activation
		* 
		* @author Thomas Griffin, Gary Jones, Juliette Reinders Folmer
		* @since 2.5.2
		*/
		require_once( get_template_directory(). '/inc/tgm/class-tgm-plugin-activation.php' );
		require_once( get_template_directory(). '/inc/tgm/plugins.php' );
	}

}
?>