<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * AJAX.
 *
 * AJAX Event Handler.
 *
 * @package Masta
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */
class Noubakery_Theme_Ajax 
{

	/**
	 * Hook in ajax handlers.
	 */
	public static function init() 
	{
		self::add_ajax_events();
	}

	/**
	 * Hook in methods - uses WordPress ajax handlers (admin-ajax).
	 */
	public static function add_ajax_events() 
	{
		
		$ajax_events = array(
			'email_contact',
			'search_products',
			'product_quick_view',
			'post_like',
			'wishlist',
			'compare',
			'quick_order',
			'remove_product_from_lists',
			'remove_product_from_cart',
			'mobile_cart_content'
		);

		foreach ( $ajax_events as $ajax_event ) {
			add_action( 'wp_ajax_noubakery_' . $ajax_event, array( __CLASS__, $ajax_event ) );
			add_action( 'wp_ajax_nopriv_noubakery_' . $ajax_event, array( __CLASS__, $ajax_event ) );
		}
	}

	public static function mobile_cart_content(){
		$status = array('status' => '0', 'html' => '', 'count' => 0);
		if( !empty($_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){
			if ( WC()->cart->get_cart_contents_count() > 0 ){
				$status['status'] = 1;
				$status['count'] = WC()->cart->get_cart_contents_count();
			}
		}
		wp_send_json($status);
	}

	public static function remove_product_from_cart(){
		$status = array('status' => '0', 'html' => '');
		if( !empty($_POST['cart_item_key']) && !empty($_POST['product_id']) && !empty($_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){
			$id = $_POST['product_id'];
			if ( $cart_item = WC()->cart->get_cart_item( $_POST['cart_item_key'] ) ) {
				WC()->cart->remove_cart_item( $_POST['cart_item_key'] );
				$product = wc_get_product( $_POST['product_id'] );
				$removed_notice  = sprintf( __( '%s removed.', 'noucake' ), $product->get_name() );
				wc_add_notice( $removed_notice );
				$status['status'] = 1;
				ob_start();
					noubakery_mini_cart();
				$status['html'] = ob_get_clean();
			}
		}

		wp_send_json($status);
	}

	public static function remove_product_from_lists(){
		$status = array('status' => '0', 'html' => '');
		if( !empty($_POST['product_id']) && !empty($_POST['type'] ) && !empty($_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){

			switch ($_POST['type']) {
				case 'wishlist':
					$delete = Noubakery_Theme_Wishlist::delete($_POST['product_id']);
					$status['status'] = $delete;
					break;
				case 'compare':
					$delete = Noubakery_Theme_Compare::delete($_POST['product_id']);
					$status['status'] = $delete;
					break;
			}
		}
		wp_send_json($status);
		exit();
	}

	public static function quick_order(){
		$status = array('status' => '0', 'html' => '');
		if( !empty($_POST['product_id'] ) && !empty($_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){
			$title = esc_html__('Order from quick order form', 'noucake');
			// Create post object
			$quick_order = array(
			  'post_title'    => esc_html__('Order from quick order form', 'noucake'),
			  'post_content'  => esc_html__('Order from quick order form', 'noucake'),
			  'post_type' 	  => 'shop_order',
			  'post_status'   => 'wc-on-hold',
			  'post_excerpt'  => esc_html($_POST['note'])
			);
			// Insert the post into the database
			$id = wp_insert_post( $quick_order );

			if(intval($id)){
				update_post_meta($id, '_created_via', 'quick_order');
				update_post_meta($id, '_billing_first_name', esc_html($_POST['name']));
				update_post_meta($id, '_billing_address_1', esc_html($_POST['address']));
				update_post_meta($id, '_billing_email', esc_html($_POST['email']));
				update_post_meta($id, '_billing_phone', esc_html($_POST['phone']));

				$data_order_date = array(
				    'comment_post_ID' => $id,
				    'comment_author' => esc_html__('WooCommerce', 'noucake'),
				    'comment_content' => esc_html__('The date customer want order bakery: ', 'noucake').esc_html($_POST['date']),
				    'comment_type' => 'order_note',
				    'comment_agent' => esc_html__('WooCommerce', 'noucake'),
				    'comment_approved' => 1,
				);
				wp_insert_comment($data_order_date);

				global $wpdb;
				$wpdb->insert( $wpdb->prefix . 'woocommerce_order_items', array(
					'order_item_name' => get_the_title($_POST['product_id']),
					'order_item_type' => 'line_item',
					'order_id'        => $id,
				) );
				if($wpdb->insert_id){
					$wpdb->query( $wpdb->prepare( "
						INSERT INTO {$wpdb->prefix}woocommerce_order_itemmeta ( order_item_id, meta_key, meta_value )
						VALUES (%s, '_product_id', %s);", $wpdb->insert_id, $_POST['product_id'] ) );
					$wpdb->query( $wpdb->prepare( "
						INSERT INTO {$wpdb->prefix}woocommerce_order_itemmeta ( order_item_id, meta_key, meta_value )
						VALUES (%s, '_qty', %s);", $wpdb->insert_id, $_POST['product_qty'] ) );
				}

				$order = wc_get_order($id);
				$mailer = WC()->mailer();
				$mails = $mailer->get_emails();
				if ( ! empty( $mails ) ) {
					foreach ( $mails as $mail ) {
						if ( $mail->id == 'new_order' || $mail->id == 'customer_invoice' ) {
							$mail->trigger( $order->get_id(), $order );
						}
					}
				}
				$status['status'] = '1';
			}

		}
		wp_send_json($status);
		exit();
	}

	public static function wishlist(){
		$status = array('status' => '0', 'html' => '');
		if( !empty($_POST['product_id'] ) && !empty($_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){
			$wishlist = true;
			switch ($_POST['do_action']) {
				case 'add':
					$wishlist = Noubakery_Theme_Wishlist::add($_POST['product_id']);
					if($wishlist){
						$status['html'] = esc_html__('Product added to wishlist.', 'noucake');
					}else{
						$status['html'] = esc_html__('Product has exists in wishlist.', 'noucake');
					}
					break;
				case 'delete':
					$wishlist = Noubakery_Theme_Wishlist::delete($_POST['product_id']);
					if($wishlist){
						$status['html'] = esc_html__('Delete from wishlist successfully.', 'noucake');
					}else{
						$status['html'] = esc_html__('Product not exists in wishlist.', 'noucake');
					}
					break;
			}

			if($wishlist){
				$status['status'] = '1';
			}
		}
		wp_send_json($status);
		exit();
	}

	public static function compare(){
		$status = array('status' => '0', 'html' => '');
		if( !empty($_POST['product_id']) && !empty($_POST['nonce']) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){
			$compare = false;
			switch ($_POST['do_action']) {
				case 'add':
					$compare = Noubakery_Theme_Compare::add($_POST['product_id']);
					if($compare){
						$status['html'] = esc_html__('Product added to compare.', 'noucake');
					}else{
						$status['html'] = esc_html__('Product has exists in compare list.', 'noucake');
					}
					$status['product_id'] = $compare;
					break;
				case 'delete':
					$compare = Noubakery_Theme_Compare::delete($_POST['product_id']);
					if($compare){
						$status['html'] = esc_html__('Delete from compare list successfully.', 'noucake');
					}else{
						$status['html'] = esc_html__('Product not exists in compare list.', 'noucake');
					}
					break;
			}

			if($compare){
				$status['status'] = '1';
			}
		}
		wp_send_json($status);
		exit();
	}

	public static function product_quick_view(){
		$status = array('status' => '0', 'html' => 'bac');

		if( !empty($_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){

			if ( ! isset( $_POST['product_id'] ) ) {
				die();
			}

			$product_id = intval( $_POST['product_id'] );

			// set the main wp query for the product
			wp( 'p=' . $product_id . '&post_type=product' );

			ob_start();

			while ( have_posts() ) : the_post();
			$all_images = noubakery_product_images(get_the_ID());
			?>
			<div id="product-<?php the_ID(); ?>" <?php post_class(); ?>>
				<div class="col-lg-5 col-md-5 col-sm-12 col-xs-12 ">
	                <div class="ps-product__thumbnail">
	                  <div class="quickview--main" data-owl-auto="true" data-owl-loop="false" data-owl-speed="10000" data-owl-gap="0" data-owl-nav="false" data-owl-dots="false" data-owl-animate-in="" data-owl-animate-out="" data-owl-item="1" data-owl-item-xs="1" data-owl-item-sm="1" data-owl-item-md="1" data-owl-item-lg="1" data-owl-nav-left="&lt;i class=&quot;fa fa-angle-left&quot;&gt;&lt;/i&gt;" data-owl-nav-right="&lt;i class=&quot;fa fa-angle-right&quot;&gt;&lt;/i&gt;">
		                    <?php
								if ( count($all_images) > 0 ) {

									foreach ($all_images as $id) {
										$images = wp_get_attachment_image_src($id, 'noubakery_458x493');
										if($images){
											?>
											<div class="ps-product__image">
							                    <img src="<?php echo esc_attr($images[0]);?>" alt="<?php the_title(); ?>"/>
							                </div>
											<?php
										}
									}
									
								} else {
									echo apply_filters( 'woocommerce_single_product_image_html', sprintf( '<div class="ps-product__image"><img src="%s" alt="%s" class="gallery-image"/></div>', wc_placeholder_img_src(), __( 'Placeholder', 'noucake' ) ), get_the_ID() );
								}

								
							?>
	                  </div>
	                  <?php if ( count($all_images) > 0 ) {?>
	                  <div class="quickview--thumbnail" data-owl-auto="true" data-owl-loop="false" data-owl-speed="10000" data-owl-gap="20" data-owl-nav="false" data-owl-dots="false" data-owl-animate-in="" data-owl-animate-out="" data-owl-item="4" data-owl-item-xs="2" data-owl-item-sm="3" data-owl-item-md="4" data-owl-item-lg="4" data-owl-nav-left="&lt;i class=&quot;fa fa-angle-left&quot;&gt;&lt;/i&gt;" data-owl-nav-right="&lt;i class=&quot;fa fa-angle-right&quot;&gt;&lt;/i&gt;">
	                  	<?php
							if ( count($all_images) > 0 ) {

								foreach ($all_images as $id) {
									$images = wp_get_attachment_image_src($id, 'noubakery_100x107');
									if($images){
										?>
										<img src="<?php echo esc_attr($images[0]);?>" alt="attachment-<?php echo esc_attr($images[0]);?>"/>
										<?php
									}
								}
								
							}
							
						?>
	                  </div>
	                  <?php }?>
	                </div>
	            </div>
	            <div class="col-lg-7 col-md-7 col-sm-12 col-xs-12 ">
	                <header>
	                  <h3 class="ps-product__name"><?php the_title();?></h3>
	                  <?php
	                  woocommerce_template_single_rating();
		    		  woocommerce_template_single_price();
		    		  woocommerce_template_single_meta();
		    		  woocommerce_template_single_add_to_cart();
	                  ?>
	                </header>
	                <?php
						/**
						 * woocommerce_single_product_summary hook.
						 */
						do_action( 'woocommerce_single_product_summary' );
					?>
	            </div>
	        </div>
			<?php
			endwhile;
			$status['status'] =  1;
			$status['html'] =  ob_get_clean();
		}

		wp_send_json($status);
		exit();
	}

	public static function search_products()
	{
		global $woocommerce;
        $search_keyword 	=  $_POST['key'];
        $suggestions = array();
        $status = array('status' => '0', 'html' => '', 'count' => 0);
        $html = '';

        if( !empty($_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){
	        
	        $args = array(
		        's'           => $search_keyword,
		        'post_type'   => 'product',
		        'post_status' => 'publish',
		        'posts_per_page' => 5,
	        );
	        $args['meta_key'] = 'total_sales';
			$args['orderby'] = 'meta_value_num'; 
	        $products = new WP_Query( $args );
	        if ( ! empty( $products->have_posts() ) ) {
	        	ob_start();?>
	        		<div class="row products">
	        			<?php
	        			$i = 1; 
	        			while ($products->have_posts()) { $products->the_post();
	        				global $post;
					        $product = wc_get_product( get_the_ID() );
					        if(!empty($product) && $i <= 4):
					        	$class = implode( ' ', array_filter( array(
						            'button',
						            'product_type_' . $product->get_type(),
						            $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
						            $product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
						        ) ) );
					        	?>

						        <?php if($i == '1'){?><div class="col-lg-6 col-md-6 col-sm-12 col-xs-12 "><?php }?>
						    	<div class="product ps-product--list ps-product--list-light mt-60">
				                    <div class="ps-product__thumbnail">
				                    	<a class="ps-product__overlay" href="<?php echo get_permalink($post->ID);?>"></a>
	      								<?php echo noubakery_post_thumbnail($post->ID);?>
				                    </div>
				                    <div class="ps-product__content">
				                      <h4 class="ps-product__title"><a href="<?php echo get_permalink($post->ID);?>"><?php echo get_the_title($post->ID);?></a></h4>
				                      <?php echo wp_kses_post(wpautop(wp_trim_words($post->post_excerpt, 10)));?>
				                      <p class="ps-product__price">
				                        <?php echo noubakery_esc($product->get_price_html()); ?>
				                      </p>
				                      <?php
								      	echo apply_filters( 'woocommerce_search_products_add_to_cart_link',
											sprintf( '<a rel="nofollow" href="%s" data-quantity="%s" data-product_id="%s" data-product_sku="%s" class="ps-btn ps-btn--xs product-item-cart %s">%s<i class="fa fa-angle-right"></i></a>',
												esc_url( $product->add_to_cart_url() ),
												esc_attr( isset( $quantity ) ? $quantity : 1 ),
												esc_attr( $product->get_id() ),
												esc_attr( $product->get_sku() ),
												esc_attr( isset( $class ) ? $class : 'button' ),
												esc_html( $product->add_to_cart_text() )
											),
										$product );
								      ?>
				                    </div>
				                </div>
				                <?php if($i == '2'){?></div><?php }?>
				                <?php if($i == '2' && $products->found_posts >= 4){?><div class="col-lg-6 col-md-6 col-sm-12 col-xs-12 "><?php }?>
				                <?php if($i == '4' && $products->found_posts >= 4){?></div><?php }?>
						        <?php
					        endif;
					        $i++;
				        }
	        			?>
	        		</div>
			    <?php
			    $html = ob_get_clean();
		        }
		        
				$status['i'] = $i;
		        $status['status'] = 1;
		        $status['count'] = $products->found_posts;
		        $status['html'] = $html;
		        wp_reset_postdata();
	    }

        wp_send_json($status);
        die();
	}

	public static function email_contact()
	{
		$status = array('status' => '0', 'html' => 'bac');

		if( !empty($_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'noubakery-theme-nonce' ) ){
			$status['status'] = 2;
			if(!empty($_POST['name']) && !empty($_POST['email']) && !empty($_POST['content']) && is_email($_POST['email'])){
				$subject = !empty($_POST['subject']) ? esc_html($_POST['subject']) : sprintf(esc_html__('[%s] Email from contact form', 'noucake'), get_bloginfo('name'));
				$message = sprintf(esc_html__('This email was sent from form contact on website %s', 'noucake'), get_bloginfo('name'))."<br/>";
				$message .= esc_html__('Name:', 'noucake')." ".esc_html($_POST['name'])."<br/>";
				$message .= esc_html__('Email:', 'noucake')." ".esc_html($_POST['email'])."<br/>";
				$message .= esc_html__('Phone:', 'noucake')." ".esc_html($_POST['phone'])."<br/>";
				$message .= esc_html__('Comments:', 'noucake')."\n ".wp_kses_post($_POST['content'])."";
				if(class_exists('Bakery_Helpers_Email')){
					Bakery_Helpers_Email::send( noubakery_get_email(), $subject, $message );
				}
				$status['status'] = 1;
			}
		}

		wp_send_json($status);
		exit();
	}

	public static function post_like() {
		// Security
		$nonce = isset( $_POST['security'] ) ? sanitize_text_field( $_POST['security'] ) : 0;
		
		if ( !wp_verify_nonce( $nonce, 'noubakery-theme-nonce' ) ) {
			exit( esc_html__( 'Not permitted', 'noucake' ) );
		}
		// Test if javascript is disabled
		$disabled = ( isset( $_POST['disabled'] ) && $_POST['disabled'] == true ) ? true : false;
		// Test if this is a comment
		$is_comment = ( isset( $_POST['is_comment'] ) && $_POST['is_comment'] == 1 ) ? 1 : 0;
		// Base variables
		$post_id = ( isset( $_POST['post_id'] ) && is_numeric( $_POST['post_id'] ) ) ? $_POST['post_id'] : '';
		
		$result = array();
		$post_users = NULL;
		$like_count = 0;

		// Get plugin options
		if ( $post_id != '' ) {

			$count = get_post_meta( $post_id, "_post_like_count", true );
			$count = ( isset( $count ) && is_numeric( $count ) ) ? $count : 0;
			
			if ( !noubakery_already_liked( $post_id, $is_comment ) ) { // Like the post

				if ( is_user_logged_in() ) { // user is logged in

					$user_id = get_current_user_id();
					$post_users = self::post_user_likes( $user_id, $post_id, $is_comment );
					
					if ( $is_comment == 1 ) {

						// Update User & Comment
						$user_like_count = get_user_option( "_comment_like_count", $user_id );
						$user_like_count =  ( isset( $user_like_count ) && is_numeric( $user_like_count ) ) ? $user_like_count : 0;
						update_user_option( $user_id, "_comment_like_count", ++$user_like_count );
						
						if ( $post_users ) {
							update_comment_meta( $post_id, "_user_comment_liked", $post_users );
						}

					} else {

						// Update User & Post
						$user_like_count = get_user_option( "_user_like_count", $user_id );
						$user_like_count =  ( isset( $user_like_count ) && is_numeric( $user_like_count ) ) ? $user_like_count : 0;
						update_user_option( $user_id, "_user_like_count", ++$user_like_count );
						
						if ( $post_users ) {
							update_post_meta( $post_id, "_user_liked", $post_users );
						}
					}

				} else { // user is anonymous

					$user_ip = noubakery_get_ip();
					$post_users = self::post_ip_likes( $user_ip, $post_id, $is_comment );
					
					// Update Post
					if ( $post_users ) {
						if ( $is_comment == 1 ) {
							update_comment_meta( $post_id, "_user_comment_IP", $post_users );
						} else { 
							update_post_meta( $post_id, "_user_IP", $post_users );
						}
					}

				}

				$like_count = ++$count;
				$response['status'] = "liked";
				$response['icon'] = noubakery_get_liked_icon();

			} else { // Unlike the post

				if ( is_user_logged_in() ) { // user is logged in

					$user_id = get_current_user_id();
					$post_users = self::post_user_likes( $user_id, $post_id, $is_comment );
					// Update User
					if ( $is_comment == 1 ) {
						$user_like_count = get_user_option( "_comment_like_count", $user_id );
						$user_like_count =  ( isset( $user_like_count ) && is_numeric( $user_like_count ) ) ? $user_like_count : 0;
						if ( $user_like_count > 0 ) {
							update_user_option( $user_id, "_comment_like_count", --$user_like_count );
						}
					} else {
						$user_like_count = get_user_option( "_user_like_count", $user_id );
						$user_like_count =  ( isset( $user_like_count ) && is_numeric( $user_like_count ) ) ? $user_like_count : 0;
						if ( $user_like_count > 0 ) {
							update_user_option( $user_id, '_user_like_count', --$user_like_count );
						}
					}
					// Update Post
					if ( $post_users ) {	
						$uid_key = array_search( $user_id, $post_users );
						unset( $post_users[$uid_key] );
						if ( $is_comment == 1 ) {
							update_comment_meta( $post_id, "_user_comment_liked", $post_users );
						} else { 
							update_post_meta( $post_id, "_user_liked", $post_users );
						}
					}
				} else { // user is anonymous
					$user_ip = noubakery_get_ip();
					$post_users = self::post_ip_likes( $user_ip, $post_id, $is_comment );
					// Update Post
					if ( $post_users ) {
						$uip_key = array_search( $user_ip, $post_users );
						unset( $post_users[$uip_key] );
						if ( $is_comment == 1 ) {
							update_comment_meta( $post_id, "_user_comment_IP", $post_users );
						} else { 
							update_post_meta( $post_id, "_user_IP", $post_users );
						}
					}
				}

				$like_count = ( $count > 0 ) ? --$count : 0; // Prevent negative number
				$response['status'] = "unliked";
				$response['icon'] = noubakery_get_unliked_icon();
			}

			if ( $is_comment == 1 ) {
				update_comment_meta( $post_id, "_comment_like_count", $like_count );
				update_comment_meta( $post_id, "_comment_like_modified", date( 'Y-m-d H:i:s' ) );
			} else { 
				update_post_meta( $post_id, "_post_like_count", $like_count );
				update_post_meta( $post_id, "_post_like_modified", date( 'Y-m-d H:i:s' ) );
			}

			$response['count'] = noubakery_post_like($post_id);
			$response['button'] = self::get_simple_likes_button($post_id);
			wp_send_json( $response );
			exit();
		}
	}


	/**
	 * Output the like button
	 * @since    0.5
	 */
	private static function get_simple_likes_button( $post_id ) {
		
		$display_love = 1;
		$output = '';

		if( isset($display_love) && !empty($display_love) ):

			$is_comment = ( NULL == $is_comment ) ? 0 : 1;
			$nonce = wp_create_nonce( 'simple-likes-nonce' ); // Security

			if ( $is_comment == 1 ) {

				$post_id_class = esc_attr( ' sl-comment-button-' . $post_id );
				$comment_class = esc_attr( ' sl-comment' );
				$like_count = get_comment_meta( $post_id, "_comment_like_count", true );
				$like_count = ( isset( $like_count ) && is_numeric( $like_count ) ) ? $like_count : 0;
			
			} else {

				$post_id_class = esc_attr( ' sl-button-' . $post_id );
				$comment_class = esc_attr( '' );
				$like_count = get_post_meta( $post_id, "_post_like_count", true );
				$like_count = ( isset( $like_count ) && is_numeric( $like_count ) ) ? $like_count : 0;
			
			}
			
			$count = noubakery_post_like($post_id);
			$icon_empty = noubakery_get_unliked_icon();
			$icon_full = noubakery_get_liked_icon();
			// Loader
			$loader = '<span id="sl-loader"></span>';

			// Liked/Unliked Variables
			if ( noubakery_already_liked( $post_id, $is_comment ) ) {
				
				$class = esc_attr( 'liked', 'noucake' );
				$title = esc_html__( 'Unlike', 'noucake' );
				$icon = $icon_full;
			
			} else {

				$class = '';
				$title = esc_html__( 'Like', 'noucake' );
				$icon = $icon_empty;
			
			}

			$output = '<a data-id="'.intval($post_id).'" class="post-like like '.esc_attr($class).'" href="#">' . esc_attr( $title ) . ''.wp_kses_post($icon).'<span><i>'.noubakery_post_like($post_id).'</i></span></a>';
			ob_start();
				noubakery_share_post();
			$output .= ob_get_clean();

		endif;
		return $output;
	} // get_simple_likes_button()

	/**
	 * Utility retrieves post meta user likes (user id array), 
	 * then adds new user id to retrieved array
	 * @since    0.5
	 */
	private static function post_user_likes( $user_id, $post_id, $is_comment ) {
		$post_users = '';
		$post_meta_users = ( $is_comment == 1 ) ? get_comment_meta( $post_id, "_user_comment_liked" ) : get_post_meta( $post_id, "_user_liked" );
		if ( count( $post_meta_users ) != 0 ) {
			$post_users = $post_meta_users[0];
		}
		if ( !is_array( $post_users ) ) {
			$post_users = array();
		}
		if ( !in_array( $user_id, $post_users ) ) {
			$post_users['user-' . $user_id] = $user_id;
		}
		return $post_users;
	} // post_user_likes()

	/**
	 * Utility retrieves post meta ip likes (ip array), 
	 * then adds new ip to retrieved array
	 * @since    0.5
	 */
	private static function post_ip_likes( $user_ip, $post_id, $is_comment ) {
		$post_users = '';
		$post_meta_users = ( $is_comment == 1 ) ? get_comment_meta( $post_id, "_user_comment_IP" ) : get_post_meta( $post_id, "_user_IP" );
		// Retrieve post information
		if ( count( $post_meta_users ) != 0 ) {
			$post_users = $post_meta_users[0];
		}
		if ( !is_array( $post_users ) ) {
			$post_users = array();
		}
		if ( !in_array( $user_ip, $post_users ) ) {
			$post_users['ip-' . $user_ip] = $user_ip;
		}
		return $post_users;
	} // post_ip_likes()

	/**
	 * Utility returns the button icon for "like" action
	 * @since    0.5
	 */
	private static function get_liked_icon() {
		$loved_icon = noubakery_noubakery_cs_get_option('noubakery_loved_icon', 'fa fa-heart');
		$icon = ' <i class="'.esc_attr( $loved_icon ).'"></i>';
		return $icon;
	} // get_liked_icon()

	/**
	 * Utility returns the button icon for "unlike" action
	 * @since    0.5
	 */
	private static function get_unliked_icon() {
		$love_icon = noubakery_noubakery_cs_get_option('noubakery_love_icon', 'fa fa-heart-o');
		$icon = '<i class="'.esc_attr( $love_icon ).'"></i>';
		return $icon;
	}
}