<?php
/**
* Demo
*
* @author nouthemes [nouthemes@gmail.com] 
* @since 1.0
*/ 

class Noubakery_Theme_Demo
{
	
	

	public static function init()
	{
		if(!defined('FS_METHOD')){
			define('FS_METHOD', 'direct');
		}

		add_filter( 'pt-ocdi/import_files', array(__CLASS__, 'import_files') );
		add_action( 'pt-ocdi/after_import', array(__CLASS__, 'ocdi_after_import') );
	}

	public static function import_files() {
	    return array(
	        array(
	            'import_file_name'         => esc_html__('Demo 1', 'noucake'),
	            'local_import_file'        => trailingslashit( get_template_directory() ) . 'demo-install/demo1/content.xml',
	            'local_import_widget_file' => trailingslashit( get_template_directory() ) . 'demo-install/demo1/widgets.wie',
	            'import_preview_image_url' => trailingslashit( get_template_directory_uri() ) . 'demo-install/demo1/screenshot.png',
	            'import_notice'            => esc_html__('The import process can take about 10 minutes. Enjoy a cup of coffee while you wait for importing.', 'noucake'),
	        ),
	    );
	}

	public static function ocdi_after_import($selected_import) {
		
		/************************************************************************
		* Import slider(s) for the current demo being imported
		*************************************************************************/
		global $wp_filesystem;

		if ( class_exists( 'RevSlider' ) ) {
			if ( 'Demo 1' === $selected_import['import_file_name'] ) {
				// Sử dụng URL từ GitHub hoặc dịch vụ lưu trữ file khác thay vì file local
				$slider_import = array(
					'https://github.com/nouthemes/nou_plugin/raw/main/bakery/bakery-demo-data/revslider/home-1.zip',
					'https://github.com/nouthemes/nou_plugin/raw/main/bakery/bakery-demo-data/revslider/home-2.zip',
					);
				foreach ($slider_import as $slider) {
					// Tải file từ URL
					$temp_file = download_url($slider);
					if (!is_wp_error($temp_file)) {
						$revslider = new RevSlider();
						$revslider->importSliderFromPost(true, true, $temp_file);
						// Xóa file tạm sau khi import
						@unlink($temp_file);
					}
				}
			}
		}


		/*Theme Options*/
		if ( class_exists( 'CSFramework' ) ) {
			if ( 'Demo 1' === $selected_import['import_file_name'] ) {
				$response = wp_remote_get(get_template_directory_uri().'/demo-install/demo1/theme-options.txt');
				if ( !is_wp_error( $response ) ) {
				  $options = json_decode($response['body'], true);
				  update_option('_noubakery_options', $options);
				}
			}
		}
		

		/************************************************************************
		* Setting Menus
		*************************************************************************/
		$left_navigation   	= get_term_by( 'slug', 'left', 'nav_menu' );
		$right_navigation 	= get_term_by( 'slug', 'right-menu', 'nav_menu' );

		set_theme_mod( 'nav_menu_locations', array(
			'left_navigation'   	=> $left_navigation->term_id,
			'right_navigation'  	=> $right_navigation->term_id,
		));

		$front_page = get_page_by_title( 'home page' );
		if(isset( $front_page ) && $front_page->ID) {
			update_option('show_on_front', 'page');
			update_option('page_on_front', $front_page->ID);
		}

		$blog = get_page_by_title( 'Blog' );
		if(isset( $blog ) && $blog->ID) {
			update_option('page_for_posts', $blog->ID);
		}


		$shop = get_page_by_title( 'Shop' );
		if(isset( $shop ) && $shop->ID) {
			update_option('woocommerce_shop_page_id', $shop->ID);
		}

		$cart = get_page_by_title( 'Cart' );
		if(isset( $cart ) && $cart->ID) {
			update_option('woocommerce_cart_page_id', $cart->ID);
		}

		$check_out = get_page_by_title( 'Checkout' );
		if(isset( $check_out ) && $check_out->ID) {
			update_option('woocommerce_checkout_page_id', $check_out->ID);
		}

		$options = get_option('_noubakery_options');

		$Wishlist = get_page_by_title( 'Wishlist' );
		if(isset( $Wishlist ) && $Wishlist->ID) {
			$options['noubakery_shop_wishlist_page_id'] = $Wishlist->ID;
		}

		$compare = get_page_by_title( 'Compare' );
		if(isset( $compare ) && $compare->ID) {
			$options['noubakery_shop_compare_page_id'] = $compare->ID;
		}

		$options['noubakery_mini_cart_enable'] = 1;
		$options['noubakery_header_top_enable'] = 1;
		$options['noubakery_header_notify_enable'] = 1;
		$options['noubakery_header_search_enable'] = 1;
		$options['noubakery_shop_enable_view'] = 1;
		$options['noubakery_shop_enable_wishlist'] = 1;
		$options['noubakery_shop_enable_compare'] = 1;
		update_option('_noubakery_options', $options);

		$post_default = noubakery_get_post_by_title('Hello world!');
		if(isset( $post_default ) && $post_default->ID) {
			wp_delete_post($post_default->ID);
		}

		try {
			self::update_terms_count();
		} catch (\Throwable $th) {
			//throw $th;
			error_log($th->getMessage());
		}

		update_option('widget_recent-posts', '');
		update_option('widget_recent-comments', '');
	}

	private static function update_terms_count(){
		global $wpdb;
		$sql = "
		UPDATE ". $wpdb->prefix ."term_taxonomy SET count = (
			SELECT COUNT(*) FROM ". $wpdb->prefix ."term_relationships rel 
				LEFT JOIN ". $wpdb->prefix ."posts po ON (po.ID = rel.object_id) 
				WHERE 
					rel.term_taxonomy_id = ". $wpdb->prefix ."term_taxonomy.term_taxonomy_id 
					AND 
					". $wpdb->prefix ."term_taxonomy.taxonomy NOT IN ('link_category')
					AND 
					po.post_status IN ('publish', 'future')
		)";
		$wpdb->get_results($sql);
	}

}
?>