<?php
/**
* Woocommerce hook
*
* @author nouthemes [nouthemes@gmail.com] 
* @since 1.0
*/ 

class Noubakery_Theme_Woocommerce
{

	public static function init()
	{
		remove_action('woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10);
		remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5);
		remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);

		remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
		remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);

		remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5);
		remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10);
		
		remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);
		
		remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10);
		remove_action('woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15);
		add_action('init', array(__CLASS__, 'view_with_session'));
		add_filter('woocommerce_add_to_cart_fragments', array(__CLASS__, 'add_to_cart_fragment'));
		remove_action('woocommerce_before_shop_loop', 'woocommerce_result_count', 20);
		add_filter('loop_shop_per_page', array(__CLASS__, 'loop_shop_per_page'));
		add_action('noubakery_shop_banner', array(__CLASS__, 'shop_banner'));

		remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_title', 5);
		remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10);
		remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);
		remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20);
		remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30);
		remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40);
		remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50);
		add_filter( 'woocommerce_product_add_to_cart_text' , array(__CLASS__, 'add_to_cart_text') );
		add_filter( 'woocommerce_product_single_add_to_cart_text' , array(__CLASS__, 'single_add_to_cart_text') );
		add_filter( 'woocommerce_sale_flash_new' , array(__CLASS__, 'sale_flash_new_text') );
		add_filter( 'woocommerce_sale_flash_hot' , array(__CLASS__, 'sale_flash_hot_text') );

		add_action( 'init', array(__CLASS__, 'process_init') );

	}

	public static function sale_flash_new_text(){
		return noubakery_noubakery_cs_get_option('noubakery_saleflash_new_text', esc_html__('New', 'noucake'));
	}

	public static function sale_flash_hot_text(){
		return noubakery_noubakery_cs_get_option('noubakery_saleflash_hot_text', esc_html__('Hot', 'noucake'));
	}

	public static function single_add_to_cart_text(){
		return noubakery_noubakery_cs_get_option('noubakery_add_to_cart_text', esc_html__( 'Add to cart', 'noucake' ));
		
	}

	public static function add_to_cart_text(){
		try {
			global $post;
			$product = wc_get_product($post->ID);
			
			if($product->get_type() == 'external'){
				return noubakery_noubakery_cs_get_option('noubakery_add_to_cart_external_text', esc_html__( 'Buy product', 'noucake' ));
			}elseif($product->get_type() == 'grouped'){
				return noubakery_noubakery_cs_get_option('noubakery_add_to_cart_grouped_text', esc_html__( 'View products', 'noucake' ));
			}elseif($product->get_type() == 'simple'){
				return noubakery_noubakery_cs_get_option('noubakery_add_to_cart_text', esc_html__( 'Add to cart', 'noucake' ));
			}elseif($product->get_type() == 'variable'){
				return noubakery_noubakery_cs_get_option('noubakery_add_to_cart_variable_text', esc_html__( 'Select options', 'noucake' ));
			}else{
				return esc_html__( 'Read more', 'noucake' );
			}
		} catch (\Throwable $th) {
			return esc_html__( 'Read more', 'noucake' );
		}
	}

	public static function process_init(){
		if( isset( $_GET['remove_item_wishlist'] ) && intval($_GET['remove_item_wishlist']) ) {
	        Noubakery_Theme_Wishlist::delete($_GET['remove_item_wishlist']);
	    }

	    if( isset( $_GET['remove_item_compare'] ) && intval($_GET['remove_item_compare']) ) {
	        Noubakery_Theme_Compare::delete($_GET['remove_item_compare']);
	    }
	}

	public static function shop_banner(){
		$shop_settings = noubakery_shop_style();
		if(!empty($shop_settings['banner'])){
			?>
			<div class="ps-shop-features">
              	<div class="row">
                    <?php foreach ($shop_settings['banner'] as $key => $value) {
                    	$col = !empty($value['col']) ? intval($value['col']) : '6';
                    	if(!empty($value['img'])):
                    	?>
                    	<div class="col-lg-<?php echo esc_attr($col);?> col-md-<?php echo esc_attr($col);?> col-sm-6 col-xs-12 ">
                    		<a href="<?php echo esc_url($value['url']);?>">
                    			<img class="mb-30" src="<?php echo esc_attr($value['img']);?>" alt="<?php esc_attr_e('Shop banner', 'noucake')?>">
                    		</a>
                    	</div>
                    	<?php
                    	endif;
                    }?>
              	</div>
            </div>
			<?php
		}
	}

	public static function loop_shop_per_page($posts_per_page){
		return (isset($_GET['product_per_page']) && intval($_GET['product_per_page'])) ? intval($_GET['product_per_page']) : noubakery_product_per_page();
	}

	public static function add_to_cart_fragment( $fragments )
	{
		global $woocommerce;
	
		ob_start();
		
		?>
		<div id="noubakery_mini_cart" class="ps-cart">
            <?php noubakery_mini_cart();?>
        </div>
		<?php
		
		$fragments['#noubakery_mini_cart'] = ob_get_clean();
		
		return $fragments;
	}

	public static function created_customer($customer_id)
	{
		if ( isset( $_POST['email'] ) ) {
 			update_user_meta($customer_id, 'billing_email', $_POST['email']);
        }

        if ( isset( $_POST['billing_address_1'] ) ) {
 			update_user_meta($customer_id, 'billing_address_1', $_POST['billing_address_1']);
        }

        if ( isset( $_POST['billing_phone'] ) ) {
 			update_user_meta($customer_id, 'billing_phone', $_POST['billing_phone']);
        }

        if(class_exists('Newsletter')){
        	if ( isset( $_POST['newsletter'] ) ) {
        		$_REQUEST['ne'] = $_POST['email'];
	 			NewsletterSubscription::instance()->subscribe(null, true);
	        }
        }
	        
	}

	public static function override_checkout_fields($fields)
	{
		$fields['billing']['billing_first_name']['placeholder'] = esc_html__('First Name *', 'noucake');
		$fields['billing']['billing_last_name']['placeholder'] = esc_html__('Last Name *', 'noucake');
		$fields['billing']['billing_email']['placeholder'] = esc_html__('Email *', 'noucake');
		$fields['billing']['billing_phone']['placeholder'] = esc_html__('Phone *', 'noucake');
		$fields['billing']['billing_city']['placeholder'] = esc_html__('Town / City *', 'noucake');
		$fields['billing']['billing_postcode']['placeholder'] = esc_html__('Postcode / ZIP *', 'noucake');
		$fields['billing']['billing_address_1']['placeholder'] = esc_html__('Address *', 'noucake');

		$fields['shipping']['shipping_address_1']['placeholder'] = esc_html__('Address *', 'noucake');
		$fields['shipping']['shipping_first_name']['placeholder'] = esc_html__('First Name *', 'noucake');
		$fields['shipping']['shipping_last_name']['placeholder'] = esc_html__('Last Name *', 'noucake');
		$fields['shipping']['shipping_city']['placeholder'] = esc_html__('Town / City *', 'noucake');
		$fields['shipping']['shipping_postcode']['placeholder'] = esc_html__('Postcode / ZIP *', 'noucake');
     	
		unset($fields['billing']['billing_company']);
		unset($fields['shipping']['shipping_company']);

     	return $fields;
	}


	public static function product_share()
	{
		echo '<div class="panel-product-line panel-product-share masta-share-post">';
			noubakery_share_post();
		echo '</div>';
	}

	public static function view_with_session()
	{
		if( !empty( $_GET['view'] ) ) {
	        if($_GET['view'] == 'gird'){
	        	$_SESSION["noubakery_products_view"] = "gird";
	        }else{
	        	$_SESSION["noubakery_products_view"] = "list";
	        }
	    }
	}

}
?>