<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme noucake for publication on ThemeForest
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

require_once get_template_directory() . '/inc/tgm/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'noucake_register_required_plugins' );
function noucake_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		array(
            'name'               => esc_html__('Bakery Theme Helpers', 'noucake'),
            'slug'               => 'bakery-helpers',
            'source'             => 'https://github.com/nouthemes/nou_plugin/raw/main/bakery/bakery-plugins/bakery-helpers.zip',
            'required'           => true,
            'version'            => '3.0.0',
            'external_url'       => '',
		),
		array(
            'name'               => esc_html__('Revolution Slider', 'noucake'),
            'slug'               => 'revslider',
            'source'             => 'https://github.com/nouthemes/nou_plugin/raw/main/bakery/bakery-plugins/revslider.zip',
            'required'           => true,
            'version'            => '6.7.31',
            'external_url'       => '',
		),
		array(
            'name'               => esc_html__('Visual Composer', 'noucake'),
            'slug'               => 'js_composer',
            'source'             => 'https://github.com/nouthemes/nou_plugin/raw/main/bakery/bakery-plugins/js_composer.zip',
            'required'           => true,
            'version'            => '8.3.1',
            'external_url'       => '',
        ),
        array(
            'name'      		=> esc_html__('Woocommerce', 'noucake'),
            'slug'      		=> 'woocommerce',
            'required'  		=> true,
            'version'           => '9.7.1',
        ),
        array(
            'name'      		=> esc_html__('WooCommerce Currency Switcher', 'noucake'),
            'slug'      		=> 'woocommerce-currency-switcher',
            'required'  		=> false,
            'version'           => '1.4.2.3',
        ),
		array(
            'name'      		=> esc_html__('Newsletter', 'noucake'),
            'slug'      		=> 'newsletter',
            'required'  		=> false,
            'version'           => '8.7.5',
		),
        array(
            'name'      		=> esc_html__('One Click Demo Import', 'noucake'),
            'slug'      		=> 'one-click-demo-import',
            'required'  		=> false,
            'version'           => '3.3.0',
		),

	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'noucake',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}