<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.9.0
 */

defined( 'ABSPATH' ) || exit;

do_action( 'woocommerce_before_cart' ); ?>

<form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
	<?php do_action( 'woocommerce_before_cart_table' ); ?>

	<div class="table-responsive">
		<table class="table">
			<thead>
				<tr>
					<th class="product-name"><?php esc_html_e( 'All Products', 'noucake' ); ?></th>
					<th class="product-price"><?php esc_html_e( 'Price', 'noucake' ); ?></th>
					<th class="product-quantity"><?php esc_html_e( 'Quantity', 'noucake' ); ?></th>
					<th class="product-subtotal"><?php esc_html_e( 'Total', 'noucake' ); ?></th>
					<th class="product-remove"></th>
				</tr>
			</thead>
			<tbody>
				<?php do_action( 'woocommerce_before_cart_contents' ); ?>

				<?php
				foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
					$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
					$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
					$product_name = apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key );

					if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
						$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
						?>
						<tr class="woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

							<td>
		                      	<div class="ps-product--cart">
		                      		<?php
										$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image('noubakery_100x107'), $cart_item, $cart_item_key );

										echo wp_kses_post($thumbnail);

										if ( ! $product_permalink ) {
											echo apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;';
										} else {
											echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key );
										}

									?>
		                      	</div>
		                      	<?php
		                      	// Meta data
								echo wc_get_formatted_cart_item_data( $cart_item );

								// Backorder notification
								if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
									echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'noucake' ) . '</p>';
								}
		                      	?>
		                    </td>

		                    <td class="product-price" data-title="<?php esc_attr_e( 'Price', 'noucake' ); ?>">
								<?php
									echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
								?>
							</td>

							<td class="product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'noucake' ); ?>">
								<?php
									if ( $_product->is_sold_individually() ) {
										$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
									} else {
										$product_quantity = woocommerce_quantity_input( array(
											'input_name'  => "cart[{$cart_item_key}][qty]",
											'input_value' => $cart_item['quantity'],
											'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
											'min_value'   => '0',
										), $_product, false );
									}

									echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item );
								?>
							</td>

							<td data-title="<?php esc_attr_e( 'Subtotal', 'noucake' ); ?>">
								<span class="total-row">
									<?php
										echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
									?>
								</span>
							</td>

							<td data-title="<?php esc_attr_e( 'Remove', 'noucake' ); ?>">
								<?php
									echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
										'woocommerce_cart_item_remove_link',
										sprintf(
											'<a href="%s" class="ps-cart-listing__remove" aria-label="%s" data-product_id="%s" data-product_sku="%s"></a>',
											esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
											'',
											esc_attr( $product_id ),
											esc_attr( $_product->get_sku() )
										),
										$cart_item_key
									);
								?>
		                    </td>

							
						</tr>
						<?php
					}
				}
				?>

			</tbody>
		</table>
	</div>

	<div class="ps-cart__process">
        <div class="row">
			<?php do_action( 'woocommerce_cart_contents' ); ?>
			<div class="col-lg-8 col-md-8 col-sm-6 col-xs-12 actions">
				<?php if ( wc_coupons_enabled() ) { ?>
					<div class="form-group form-group--icon ps-cart__promotion coupon">
						<div class="icon-wrap"><i class="fa fa-angle-right"></i>
							<input type="text" name="coupon_code" class="form-control input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'noucake' ); ?>" /> 
							<input type="hidden" class="button" name="apply_coupon" value="<?php esc_attr_e( 'Apply coupon', 'noucake' ); ?>" />
						</div>
						<button type="submit" class="ps-btn ps-btn--sm mt-10"><?php esc_html_e( 'Apply coupon', 'noucake' ); ?></button>
						<?php do_action( 'woocommerce_cart_coupon' ); ?>
					</div>
				<?php } ?>

				<div class="form-groupform-order">
	                <a class="ps-cart__shopping btn-black back-to-shop" href="<?php echo esc_url(get_permalink(get_option('woocommerce_shop_page_id')));?>"><?php esc_html_e('Continue Shopping', 'noucake');?></a>
	            </div>

				

				<?php do_action( 'woocommerce_cart_actions' ); ?>

				<?php wp_nonce_field( 'woocommerce-cart' ); ?>
			</div>
			<?php do_action( 'woocommerce_after_cart_contents' ); ?>

			<div class="col-lg-4 col-md-4 col-sm-6 col-xs-12 ">
                <div class="ps-cart__total cart-collaterals">
                	<?php do_action( 'woocommerce_cart_collaterals' ); ?>
                </div>
            </div>
		</div>
	</div>

	<?php do_action( 'woocommerce_after_cart_table' ); ?>
</form>

<?php do_action( 'woocommerce_after_cart' ); ?>
