<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.6.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $post, $product;

// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}

$shop_settings = noubakery_shop_style();

$class = implode( ' ', array_filter( array(
					            'button',
					            'product_type_' . $product->get_type(),
					            $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
					            $product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
					        ) ) );
?>
<div class="ps-product" data-mh="abc">
	<?php do_action( 'woocommerce_before_shop_loop_item' );?>
	<div class="ps-product__thumbnail">
	  <?php woocommerce_show_product_loop_sale_flash();?>
	  <a class="ps-product__overlay" href="<?php the_permalink();?>"></a>
	  <?php echo noubakery_post_thumbnail($post->ID, 'noubakery_262x283');?>
	  <ul class="ps-product__action">
	  
	  	<?php if(!empty($shop_settings['quick_view'])):?>
	        <li><a data-product_id="<?php echo esc_attr($product->get_id());?>" class="product-quickview popup-modal" href="#quickview-modal" data-effect="mfp-zoom-out" data-tooltip="<?php esc_attr_e('View', 'noucake');?>"><i class="ps-icon--search"></i></a></li>
	    <?php endif;?>

	    <?php if(!empty($shop_settings['wishlist'])):?>
	        <li><a class="product-wishlist" data-product_id="<?php echo esc_attr($product->get_id());?>" href="#" data-tooltip="<?php esc_attr_e('Add to wishlist', 'noucake');?>"><i class="ps-icon--heart"></i></a></li>
	    <?php endif;?>

	    <?php if(!empty($shop_settings['compare'])):?>
	        <li><a class="product-compare" data-product_id="<?php echo esc_attr($product->get_id());?>" href="#" data-tooltip="<?php esc_attr_e('Compare', 'noucake');?>"><i class="ps-icon--reload"></i></a></li>
	    <?php endif;?>

	    <?php if(!empty($shop_settings['add_to_cart'])):?>
	    <li>
	    	<?php 
	    	echo apply_filters( 'woocommerce_loop_add_to_cart_link',
				sprintf( '<a rel="nofollow" href="%s" data-quantity="%s" data-product_id="%s" data-product_sku="%s" class="product-item-cart %s" data-tooltip="%s"><i class="ps-icon--shopping-cart"></i></a>',
					esc_url( $product->add_to_cart_url() ),
					esc_attr( isset( $quantity ) ? $quantity : 1 ),
					esc_attr( $product->get_id() ),
					esc_attr( $product->get_sku() ),
					esc_attr( isset( $class ) ? $class : 'button' ),
					esc_html( $product->add_to_cart_text() )
				),
			$product );
	    	?>
	    </li>
	    <?php endif;?>

	  </ul>
	</div>
	<div class="ps-product__content">
		<?php do_action('woocommerce_before_shop_loop_item_title');?>
		<a class="ps-product__title" href="<?php the_permalink();?>">
			<?php do_action( 'woocommerce_shop_loop_item_title' );?>
		</a>
		<?php do_action('woocommerce_after_shop_loop_item_title');?>
	  	<div class="ps-product__category">
	  		<?php echo wp_kses_post(wc_get_product_category_list( $product->get_id(), '', '', '' )); ?>
	  	</div>
	    <?php woocommerce_template_loop_rating();?>
	    <?php woocommerce_template_loop_price();?>
	</div>
	<?php do_action( 'woocommerce_after_shop_loop_item' );?>
</div>