<?php
/**
 * The template for displaying product widget entries
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-widget-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.5.5
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

global $product;

if ( ! is_a( $product, 'WC_Product' ) ) {
  return;
}

$class = implode( ' ', array_filter( array(
            'button',
            'product_type_' . $product->get_type(),
            $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
            $product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
        ) ) );
?>
<div class="product ps-product--sidebar">
  <?php do_action( 'woocommerce_widget_product_item_start', $args ); ?>
    <div class="ps-product__thumbnail">
    	<a class="ps-product__overlay" href="<?php echo esc_url( $product->get_permalink() ); ?>"></a>
    	<?php echo wp_kses_post($product->get_image('noubakery_75x81')); ?>
    </div>
    <div class="ps-product__content">
      	<h4 class="ps-product__title">
      		<a href="<?php echo esc_url( $product->get_permalink() ); ?>"><?php echo esc_html($product->get_name()); ?></a>
      	</h4>
      	<p class="ps-product__price"><?php echo noubakery_esc($product->get_price_html()); ?></p>
      	<?php
      	echo apply_filters( 'woocommerce_sidebar_add_to_cart_link',
			sprintf( '<a rel="nofollow" href="%s" data-quantity="%s" data-product_id="%s" data-product_sku="%s" class="ps-btn ps-btn--xs product-item-cart %s">%s</a>',
				esc_url( $product->add_to_cart_url() ),
				esc_attr( isset( $quantity ) ? $quantity : 1 ),
				esc_attr( $product->get_id() ),
				esc_attr( $product->get_sku() ),
				esc_attr( isset( $class ) ? $class : 'button' ),
				esc_html( $product->add_to_cart_text() )
			),
		$product );
      	?>
    </div>
  <?php do_action( 'woocommerce_widget_product_item_end', $args ); ?>  
</div>