<?php
/**
 * Show options for ordering
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/loop/orderby.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     9.7.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$id_suffix = wp_unique_id();
$shop_style = noubakery_shop_style();
$view = $shop_style['view'];
$product_per_page = ( isset( $_GET['product_per_page'] ) && intval( $_GET['product_per_page'] ) ) ? intval( $_GET['product_per_page'] ) : noubakery_product_per_page();
?>
<form class="woocommerce-ordering" method="get">
	<div class="col-lg-5 col-md-4 col-sm-4 col-xs-12">
        <div class="form-group">
        	<label for="woocommerce-orderby-<?php echo esc_attr( $id_suffix ); ?>"> <?php esc_html_e( 'Sort by', 'noucake' ); ?>:</label>
            <select name="orderby" id="woocommerce-orderby-<?php echo esc_attr( $id_suffix ); ?>" class="orderby ps-select">
                <?php foreach ( $catalog_orderby_options as $id => $name ) : ?>
                    <option value="<?php echo esc_attr( $id ); ?>" <?php selected( $orderby, $id ); ?>><?php echo esc_html( $name ); ?></option>
                <?php endforeach; ?>
            </select>
            <?php wc_query_string_form_fields( null, array( 'orderby', 'submit', 'paged', 'product-page', 'product_per_page' ) ); ?>
        </div>
    </div>
    <div class="col-lg-5 col-md-4 col-sm-4 col-xs-12">
        <div class="form-group">
            <label><?php esc_html_e( 'Show', 'noucake' ); ?>:</label>
            <select class="ps-select" name="product_per_page">
                <option value="9" <?php selected( $product_per_page, '9' ); ?>><?php esc_html_e( '9 Items', 'noucake' ); ?></option>
                <option value="12" <?php selected( $product_per_page, '12' ); ?>><?php esc_html_e( '12 Items', 'noucake' ); ?></option>
                <option value="15" <?php selected( $product_per_page, '15' ); ?>><?php esc_html_e( '15 Items', 'noucake' ); ?></option>
                <option value="18" <?php selected( $product_per_page, '18' ); ?>><?php esc_html_e( '18 Items', 'noucake' ); ?></option>
                <option value="21" <?php selected( $product_per_page, '21' ); ?>><?php esc_html_e( '21 Items', 'noucake' ); ?></option>
                <?php 
                $items = noubakery_theme_option( 'product_per_page' );
                if ( $items == 'custom' ) {
                    $items = noubakery_theme_option( 'product_per_page_custom', 9 );
                ?>
                <option value="<?php echo esc_attr( $items ); ?>" <?php selected( $product_per_page, $items ); ?>><?php echo sprintf( esc_html__( '%s Items', 'noucake' ), $items ); ?></option>
                <?php } ?>
            </select>
        </div>
    </div>
    <div class="col-lg-2 col-md-4 col-sm-4 col-xs-12">
        <ul class="ps-shop-switch">
            <li class="<?php if ( $view == 'grid' ) { echo 'active'; } ?>">
                <a href="<?php echo esc_url( add_query_arg( 'view', 'grid' ) ); ?>">
                    <i class="fa fa-th"></i>
                </a>
            </li>
            <li class="<?php if ( $view == 'list' ) { echo 'active'; } ?>">
                <a href="<?php echo esc_url( add_query_arg( 'view', 'list' ) ); ?>">
                    <i class="fa fa-list"></i>
                </a>
            </li>
        </ul>
    </div>
</form>
