<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 9.7.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

global $product;

if ( ! comments_open() ) {
    return;
}

?>

<div id="reviews" class="woocommerce-Reviews">
    <div id="comments" class="panel-review">
        <p class="panel-review-title woocommerce-Reviews-title">
        <?php
            $count = $product->get_review_count();
            if ( $count && wc_review_ratings_enabled() ) {
                /* translators: 1: reviews count 2: product name */
                $reviews_title = sprintf( esc_html( _n( '%1$s review for %2$s', '%1$s reviews for %2$s', $count, 'noucake' ) ), esc_html( $count ), '<span>' . get_the_title() . '</span>' );
                echo apply_filters( 'woocommerce_reviews_title', $reviews_title, $count, $product ); // WPCS: XSS ok.
            } else {
                esc_html_e( 'Reviews', 'noucake' );
            }
        ?>
        </p>

        <?php if ( have_comments() ) : ?>

            <div class="commentlist">
                <?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'noubakery_comment_callback_product', 'style' => 'div' ) ) ); ?>
            </div>

            <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
                echo '<nav class="woocommerce-pagination">';
                paginate_comments_links(
                    apply_filters(
                        'woocommerce_comment_pagination_args',
                        array(
                            'prev_text' => is_rtl() ? '&rarr;' : '&larr;',
                            'next_text' => is_rtl() ? '&larr;' : '&rarr;',
                            'type'      => 'list',
                        )
                    )
                );
                echo '</nav>';
            endif; ?>

        <?php else : ?>

            <p class="woocommerce-noreviews"><?php esc_html_e( 'There are no reviews yet.', 'noucake' ); ?></p>

        <?php endif; ?>
    </div>

    <div class="ps-product__review">
    <?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>

        <div id="review_form_wrapper">
            <div id="review_form">
                <?php
                $commenter = wp_get_current_commenter();
                $comment_form = array(
                    'id_form'           => 'commentform',
                    'class_form'        => 'comment-form',
                    'id_submit'         => 'submit',
                    'class_submit'      => 'submit',
                    'name_submit'       => 'submit',
                    'title_reply'       => esc_html__( 'ADD YOUR REVIEW', 'noucake' ),
                    'title_reply_to'    => esc_html__( 'Leave a Reply to %s', 'noucake' ),
                    'cancel_reply_link' => esc_html__( 'Cancel Reply', 'noucake' ),
                    'title_reply_before'  => '<span id="reply-title" class="comment-reply-title" role="heading" aria-level="3">',
                    'title_reply_after'   => '</span>',
                    'format'            => 'xhtml',
                    'comment_notes_after' => '',
                    'logged_in_as'        => '',
                    'comment_notes_before' => '',
                    'submit_button'        => '<button type="submit" id="%2$s" name="%1$s" class="%3$s ps-btn ps-btn--sm">%4$s</button>',
                    'submit_field'         => '<div class="form-group">%1$s %2$s</div>',
                    'comment_field'       => '',
                );

                $name_email_required = (bool) get_option( 'require_name_email', 1 );
                
                $fields = array();
                
                $fields['author'] = '<div class="row"><div class="col-md-4 col-sm-12 col-xs-12">
                    <div class="form-group">
                    <label class="panel-review-label" for="author">'.esc_html__('Name', 'noucake').' '.($name_email_required ? '*' : '').'</label>
                    <input id="author" class="form-control" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
                    '" size="30" autocomplete="name" '.($name_email_required ? 'required' : '').'/></div></div>';

                $fields['email'] = '<div class="col-md-4 col-sm-12 col-xs-12">
                    <div class="form-group">
                    <label class="panel-review-label" for="email">'.esc_html__('Email', 'noucake').' '.($name_email_required ? '*' : '').'</label>
                    <input id="email" class="form-control" name="email" type="email" value="' . esc_attr( $commenter['comment_author_email'] ) .
                    '" size="30" autocomplete="email" '.($name_email_required ? 'required' : '').'/></div></div>';

                $fields['url'] = '<div class="col-md-4 col-sm-12 col-xs-12">
                    <div class="form-group">
                    <label class="panel-review-label" for="url">'.esc_html__('Website', 'noucake').'</label>
                    <input id="url" class="form-control" name="url" type="url" value="' . esc_attr( $commenter['comment_author_url'] ) .
                    '" size="30" autocomplete="url" /></div></div></div>';

                $comment_form['fields'] = apply_filters('comment_form_default_fields', $fields);

                // Setup account page URL for must_log_in message
                $account_page_url = wc_get_page_permalink('myaccount');
                if ($account_page_url) {
                    /* translators: %s opening and closing link tags respectively */
                    $comment_form['must_log_in'] = '<p class="must-log-in">' . sprintf(esc_html__('You must be %1$slogged in%2$s to post a review.', 'noucake'), '<a href="' . esc_url($account_page_url) . '">', '</a>') . '</p>';
                }

                if (wc_review_ratings_enabled()) {
                    // Sử dụng input hidden thay vì select để tránh WooCommerce thêm stars
                    $comment_form['comment_field'] = '<div class="form-group">
                        <label class="panel-review-label">'.esc_html__('Your rating', 'noucake') . (wc_review_ratings_required() ? '&nbsp;<span class="required">*</span>' : '') .'</label>
                        <div class="custom-rating-wrapper">
                            <select class="ps-rating" name="rating" id="rating" '.( wc_review_ratings_required() ? 'required' : '' ).'>
                                <option value="0">0</option>
                                <option value="1">1</option>
                                <option value="2">2</option>
                                <option value="3">3</option>
                                <option value="4">4</option>
                                <option value="5">5</option>
                            </select>
                        </div>
                    </div>';
                }

                $comment_form['comment_field'] .= '<div class="form-group">
                    <label class="panel-review-label" for="comment">'.esc_html__('Your comment', 'noucake').'&nbsp;<span class="required">*</span></label>
                    <textarea class="form-control" name="comment" id="comment" aria-required="true" required></textarea>
                </div>';

                comment_form(apply_filters('woocommerce_product_review_comment_form_args', $comment_form));
                ?>
            </div>
        </div>

    <?php else : ?>

        <p class="woocommerce-verification-required"><?php esc_html_e( 'Only logged in customers who have purchased this product may leave a review.', 'noucake' ); ?></p>

    <?php endif; ?>
    </div>

    <div class="clear"></div>
</div>
