<?php
/**
 * Single Product Meta
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/meta.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     9.7.0
 */

use Automattic\WooCommerce\Enums\ProductType;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $product;

$stock = wc_get_stock_html( $product );
if ( empty( $stock ) ) {
	$stock = esc_html__( 'In Stock', 'noucake' );
}

$stock_enable = noubakery_theme_option( 'product_meta_enable_stock' );
$tags_enable  = noubakery_theme_option( 'product_meta_enable_tags' );
$cat_enable   = noubakery_theme_option( 'product_meta_enable_category' );
$sku_enable   = noubakery_theme_option( 'product_meta_enable_sku' );
?>

<div class="ps-product__meta">

	<?php do_action( 'woocommerce_product_meta_start' ); ?>

	<?php if ( ! empty( $stock_enable ) ) : ?>
		<p><span><?php esc_html_e( 'Availability', 'noucake' ); ?>: </span> 
		<?php echo noubakery_esc( $product->is_in_stock() ? $stock : esc_html__( 'Out Of Stock', 'noucake' ) ); ?></p>
	<?php endif; ?>

	<?php if ( ! empty( $sku_enable ) && wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( ProductType::VARIABLE ) ) ) : ?>
		<p class="panel-product-line panel-product-info">  
			<span class="panel-product-label"><?php esc_html_e( 'SKU:', 'noucake' ); ?></span> 
			<span class="sku-for-default sku-value">
				<?php echo noubakery_esc( ( $sku = $product->get_sku() ) ? $sku : esc_html__( 'N/A', 'noucake' ) ); ?>
			</span>
		</p>
	<?php endif; ?>

	<?php if ( ! empty( $cat_enable ) ) : ?>
		<?php echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="posted_in">' . _n( 'Category:', 'Categories:', count( $product->get_category_ids() ), 'noucake' ) . ' ', '</span>' ); ?>
	<?php endif; ?>

	<?php if ( ! empty( $tags_enable ) ) : ?>
		<?php echo wc_get_product_tag_list( $product->get_id(), ', ', '<span class="tagged_as">' . _n( 'Tag:', 'Tags:', count( $product->get_tag_ids() ), 'noucake' ) . ' ', '</span>' ); ?>
	<?php endif; ?>

	<?php do_action( 'woocommerce_product_meta_end' ); ?>

</div>
